@@ -1,5 +1,4 @@
-extern crate generator;
-use generator::state_machine_generator;
+use gentian::gentian;
 
 #[cfg(test)]
 struct MyGenerator {
@@ -20,8 +19,8 @@ impl MyGenerator {
         }
     }
 
-    #[state_machine_generator]
-    #[fsa_attr(state=self.my_state_1)]
+    #[gentian]
+    #[gentian_attr(state=self.my_state_1)]
     pub fn test_simple(&mut self) {
         loop {
             println!("Hello, ");
@@ -36,8 +35,8 @@ impl MyGenerator {
     }
 
     // state_name , return_default_value
-    #[state_machine_generator]
-    #[fsa_attr(state=self.my_state_2,ret_val=0u32)]
+    #[gentian]
+    #[gentian_attr(state=self.my_state_2,ret_val=0u32)]
     pub fn get_odd(&mut self) -> u32 {
         loop {
             if self.num % 2 == 1 {
